# How to Contribute

Thank you for taking the time to contribute to this project. We welcome small patches related to bug fixes and documentation, but we do not plan to make any major changes to this repository.

## Contributor License Agreement
This work is licensed under the **MIT license (code) and Creative Commons Attribution 4.0 International license (for documentation)**. 
<!--Replace these sentences to appropriate reflect the license chosen in your project-->
You are free to share and adapt the material for any academic purpose, as long as you provide attribution (cite the articles, give appropriate credit, provide a link to the license, and indicate if changes were made) in any reasonable manner, but not in any way that suggests the licensor endorses you or your use, and with no additional restrictions.
<!--Replace these sentences to appropriate reflect the license chosen in your project-->
